@@ -27,6 +27,11 @@ FieldView::FieldView(ReversiGame &reversiGame, QWidget *parent) :
     connect(scene_, SIGNAL(playerStep(int,int)), parent, SLOT(slotPlayerStep(int,int)));
 }
 
+FieldView::~FieldView()
+{
+    delete scene_;
+}
+
 QSize FieldView::sizeHint () const
 {
     return QSize(scene_->fieldWidth(), scene_->fieldHeight());
