@@ -34,7 +34,7 @@ private:
     virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent *event);
 
 private slots:
-    void slotStepComplete();
+    void slotStepComplete(bool isUndo);
     void slotNewGame(int);
     void slotAnimationStep();
 
